@@ -10,7 +10,6 @@ use Algorithm::Dependency::Ordered;
 use HPC::Runner::Command::submit_jobs::Utils::Scheduler::Batch;
 use POSIX;
 use String::Approx qw(amatch);
-use Text::ANSITable;
 use Text::ASCIITable;
 use Try::Tiny;
 
@@ -76,8 +75,9 @@ sub schedule_jobs {
         $self->schedule( $dep->schedule_all );
     }
     catch {
-      $self->app_log->fatal('There was a problem creating your schedule. Aborting mission!');
-      exit 1;
+        $self->app_log->fatal(
+            'There was a problem creating your schedule. Aborting mission!');
+        exit 1;
     }
 
 }
@@ -132,6 +132,8 @@ sub sanity_check_schedule {
                         "No potential matches were found for dependency $r");
                 }
             }
+            else{
+            }
 
             $y++;
         }
@@ -139,6 +141,9 @@ sub sanity_check_schedule {
         $depstring = join( ", ", @{$ref} );
         push( @$row, $depstring );
 
+        my $count_cmd = $self->jobs->{ $job }->count_cmds;
+        push(@$row, $count_cmd);
+
         push( @rows, $row );
         $x++;
     }
@@ -153,13 +158,13 @@ sub sanity_check_schedule {
             "Here is your tabular dependency list in alphabetical order");
     }
     else {
-        $t->setCols( [ "JobName", "Deps" ] );
+        $t->setCols( [ "JobName", "Deps", "Task Count" ] );
         map { $t->addRow($_) } @rows;
         $self->app_log->info(
             "Here is your tabular dependency list in alphabetical order");
     }
 
-    say $t;
+    $self->app_log->info("\n\n".$t);
 
     return $search;
 }
@@ -249,6 +254,8 @@ sub chunk_commands {
     $self->reset_batch_counter;
 }
 
+#TODO put arrays in oen place, batches in another
+
 =head3 resolve_max_array_size
 
 Arrays should not be greater than the max_array_size variable
@@ -264,7 +271,6 @@ sub resolve_max_array_size {
     my $number_of_batches = shift;
     my $cmd_size          = shift;
 
-    #TODO There must be a better way of doing this
     if ( ( $cmd_size / $number_of_batches ) <= ( $self->max_array_size + 1 ) ) {
         return $number_of_batches;
     }
@@ -419,8 +425,11 @@ sub assign_batch_tags {
                     push( @batch_deps, $dep );
                 }
             }
-            else{
-              $self->app_log->warn('You are using an unknown directive with #TASK '."\n$line\nDirectives should be one of 'tags' or 'deps'");
+            else {
+                $self->app_log->warn(
+                        'You are using an unknown directive with #TASK '
+                      . "\n$line\nDirectives should be one of 'tags' or 'deps'"
+                );
             }
         }
     }
@@ -459,17 +468,10 @@ sub process_batch_deps {
     my $self  = shift;
     my $batch = shift;
 
-    my $tags;
-
     return unless $self->jobs->{ $self->current_job }->submit_by_tags;
     return unless $self->jobs->{ $self->current_job }->has_deps;
 
-    if ( $batch->has_batch_deps ) {
-        $tags = $batch->batch_deps;
-    }
-    else {
-        $tags = $batch->batch_tags;
-    }
+    my $tags = $batch->batch_tags;
 
     my $scheduler_index =
       $self->search_batches( $self->jobs->{ $self->current_job }->deps, $tags );
@@ -501,7 +503,6 @@ sub search_batches {
         foreach my $dep_batch ( @{$dep_batches} ) {
 
             #Changing this to return the index
-            ##TODO UPDATE THIS FOR MULTIPLE BATCHES WITHIN ARRAY
             push( @scheduler_index, $x )
               if $self->search_tags( $dep_batch->batch_tags, $tags );
 
